package com.lqkj.cmlcp.module.api.domain;

import com.alibaba.excel.annotation.ExcelProperty;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.lqkj.cmlcp.utils.JsonArrayStringConverter;
import io.hypersistence.utils.hibernate.type.json.JsonType;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.persistence.*;
import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import org.hibernate.annotations.Type;

@Entity
@Table(name = "api_info")
@Getter
@Setter
@NoArgsConstructor
@AllArgsConstructor
public class ApiInfo implements java.io.Serializable{
    @Id
    @Column(name = "id")
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Integer id;

    @ExcelProperty(value = "api名字")
    @Column(name = "name")
    @Schema(description = "api名字")
    private String name;

    @Column(name = "method")
    @Schema(description = "参数类型")
    private String method;

    @Column(name = "url")
    @Schema(description = "请求地址")
    private String url;

    @Type(JsonType.class)
    @Column(name = "headers", columnDefinition = "jsonb")
    @Schema(description = "请求头")
    private JSONObject headers;

    @Type(JsonType.class)
    @Column(name = "params", columnDefinition = "jsonb")
    @Schema(description = "请求参数")
    private JSONObject params;

    @ExcelProperty(value = "数据", converter = JsonArrayStringConverter.class)
    @Type(JsonType.class)
    @Column(name = "data", columnDefinition = "jsonb")
    @Schema(description = "请求体")
    private JSONArray data;

    @Column(name = "type")
    @ExcelProperty(value = "api类型")
    @Schema(description = "api类型, 1 rest; 2 static; 3 直接查询数据库")
    private Integer type;

}


