package com.lqkj.cmlcp.module.api.service.impl;

import com.alibaba.excel.EasyExcel;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.lqkj.cmlcp.module.api.domain.ApiInfo;
import com.lqkj.cmlcp.module.api.repository.ApiInfoRepository;
import com.lqkj.cmlcp.module.api.service.ApiInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.Statement;
import java.util.List;

@Service
@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
public class ApiInfoServiceImpl implements ApiInfoService {


    @Autowired
    private ApiInfoRepository apiInfoRepository;
    @Override
    @Transactional
    public void saveApi(ApiInfo apiInfo) {
        if (apiInfo.getType().equals(3)) apiInfo.setData(null);
        apiInfoRepository.save(apiInfo);
    }

    @Override
    public List<ApiInfo> findAll(String name, Integer type) {
        return apiInfoRepository.findAllByType(name, type);
    }

    @Override
    public void delete(List<Integer> ids) {
        apiInfoRepository.deleteAllById(ids);
    }

    @Override
    public ApiInfo findById(Integer id) {
        ApiInfo apiInfo = apiInfoRepository.findById(id).get();
        switch (apiInfo.getType()) {
            case 3 -> encapsuLationDbData(apiInfo);
            case 4 -> System.out.println("暂不支持该类型");
        }
        return apiInfo;
    }

    @Override
    public void importExcel(MultipartFile file) {
        try {
            List<ApiInfo> apiInfos = EasyExcel.read(file.getInputStream()).head(ApiInfo.class).sheet().doReadSync();
            apiInfoRepository.saveAll(apiInfos);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 封装数据库数据
     * @param apiInfo
     */
    private void encapsuLationDbData(ApiInfo apiInfo) {
        if (apiInfo.getData() != null) return;
        JSONObject params = apiInfo.getParams();
        String url = params.get("url").toString();
        String user = params.get("user").toString();
        String password = params.get("password").toString();
        try {
            // 建立数据库连接
            Class.forName(params.get("driver").toString());
            Connection conn = DriverManager.getConnection(url, user, password);
            // 创建Statement对象来执行SQL语句
            Statement stmt = conn.createStatement();
            // 执行查询并获取结果
            ResultSet rs = stmt.executeQuery(params.get("sql").toString());
            // 遍历结果集
            JSONArray objects = new JSONArray();
            while (rs.next()) {
                JSONObject jsonObject = new JSONObject();
                for (int i = 1; i <= rs.getMetaData().getColumnCount(); i++) {
                    String key = rs.getMetaData().getColumnName(i);
                    jsonObject.put(key, rs.getObject(key));
                }
                objects.add(jsonObject);
            }
            apiInfo.setData(objects);
            // 关闭结果集、Statement和连接
            rs.close();
            stmt.close();
            conn.close();
            apiInfoRepository.save(apiInfo);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
