package com.lqkj.cmlcp.module.authority.controller;

import com.lqkj.cmlcp.message.Result;
import com.lqkj.cmlcp.module.authority.domain.RoleInfo;
import com.lqkj.cmlcp.module.authority.service.RoleInfoService;
import com.lqkj.cmlcp.module.jwt.service.JwtService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/role")
@Tag(name = "角色管理", description = "角色管理")
public class RoleInfoController {

    
    
    @Autowired
    private RoleInfoService roleInfoService;

    @Autowired
    private JwtService jwtService;
    
    
    @Operation(
            summary = "5.3.14 角色列表接口",
            description = "5.3.14 角色列表接口"
    )
    @PostMapping("/all")
    public Result<List<RoleInfo>> allRoles() {
        return Result.ok(roleInfoService.allRoles(), "查询全部角色列表");
    }

    @Operation(
            summary = "5.3.15 角色分页接口",
            description = "5.3.15 角色分页接口",
            parameters = {
                    @Parameter(name = "roleName", description = "角色名称"),
                    @Parameter(name = "page", description = "页码"),
                    @Parameter(name = "pageSize", description = "每页数据条数")
            }
    )
    @PostMapping("/pageQuery")
    public Result<Page<RoleInfo>> pageQuery(@RequestParam(required = false, defaultValue = "") String roleName,
                                            @RequestParam(required = false, defaultValue = "0") Integer page,
                                            @RequestParam(required = false, defaultValue = "10") Integer pageSize) {
        return Result.ok(roleInfoService.pageQuery(roleName, page, pageSize), "角色分页接口");
    }

    @Operation(
            summary = "5.1.3.29 获取角色详情接口",
            description = "5.1.3.29 获取角色详情接口",
            parameters = {
                    @Parameter(name = "roleId", description = "角色ID", required = true)
            }
    )
    @PostMapping("/detail")
    public Result<RoleInfo> detail(@RequestParam Integer roleId) {
        return Result.ok(roleInfoService.detail(roleId), "获取角色详情");
    }

    @Operation(
            summary = "5.1.3.16 角色保存接口",
            description = "5.1.3.16 角色保存接口",
            requestBody = @io.swagger.v3.oas.annotations.parameters.RequestBody(
                    description = "角色信息实体",
                    required = true,
                    content = @Content(
                            mediaType = "application/json",
                            schema = @Schema(implementation = RoleInfo.class)
                    )
            )
    )
    @PostMapping("/save")
    public Result<String> save(@RequestBody RoleInfo roleInfo) {
        String msg = roleInfoService.save(roleInfo);
        if (StringUtils.isNotBlank(msg)) return Result.fail(msg);
        return Result.ok(null, "角色保存接口");
    }

    @Operation(
            summary = "5.1.3.17 权限树接口",
            description = "5.1.3.17 权限树接口"
    )
    @PostMapping("/authTree")
    public Result authTree(HttpServletRequest request) {
        String authHeader = request.getHeader("Authorization");
        String userCode = jwtService.decryptUsernameWithHeader(authHeader);
        return Result.ok(roleInfoService.queryAuthTree(userCode), "获取权限树接口");
    }

    @Operation(
            summary = "5.1.3.18 角色删除接口",
            description = "5.1.3.18 角色删除接口",
            parameters = {
                    @Parameter(name = "roleIds", description = "角色ID列表")
            }
    )
    @PostMapping("/delete")
    public Result<String> delete(@RequestParam List<Integer> roleIds) {
        String msg = roleInfoService.delete(roleIds);
        if (StringUtils.isNotBlank(msg)) return Result.fail("角色【" + msg + "】需要先删除关联用户！");
        return Result.ok(null, "角色删除接口");
    }
}
