package com.lqkj.cmlcp.module.authority.domain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonProperty;
import jakarta.persistence.*;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;

import java.util.Collection;
import java.util.Date;
import java.util.List;

@Entity
@Table(name = "user_info")
@Accessors(chain = true)
@Data(staticConstructor = "create")
@NoArgsConstructor
@AllArgsConstructor
public class UserInfo implements UserDetails {

	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	@Schema(description = "用户ID")
	private Integer Id;

	@Schema(description = "登录账号")
	private String userCode;

	@Schema(description = "显示名称")
	private String displayName;

	@Schema(description = "密码")
	@JsonProperty(access = JsonProperty.Access.WRITE_ONLY)
	private String password;

	@Schema(description = "授权码")
	private String authorizationCode;

	@Schema(description = "头像图片地址")
	private String headImg;

	@Schema(description = "文件存储路径")
	private String fileSavePath;

	@Schema(description = "是否有审核权限")
	private Boolean hasAuth;

	@Schema(description = "是否锁定")
	private Boolean locking;

	@Schema(description = "登录错误次数")
	private Integer loginErrorCount;

	@Schema(description = "锁定时间")
	@JsonFormat(pattern = "YYYY-MM-dd HH:mm:ss", timezone = "Asia/Shanghai")
	private Date lockTime;

	@JsonFormat(pattern = "YYYY-MM-dd HH:mm:ss", timezone = "Asia/Shanghai")
	@Schema(description = "更新时间")
	private Date updateTime;

	@Schema(description = "是否能进入后台")
	private Boolean hasManage;

	@Transient
	@Schema(description = "角色列表")
	private List<RoleInfo> roleInfoList;

	@Transient
	@Schema(description = "角色ID数组")
	private List<Integer> roleIds;

	@Transient
	private String roleNames;

	/**
	 * @Description 得到用户的角色列表
	 */
	@Transient
    private Collection<? extends GrantedAuthority> authorities;
	/**
	 * 判断用户是否为过期
	 */
	@Transient
    private boolean accountNonExpired = true;
	/**
	 * 判断用户是否为锁定
	 */
	@Transient
    private boolean accountNonLocked = true;
	/**
	 * 判断密码是否未过期
	 */
	@Transient
    private boolean credentialsNonExpired = true;
	/**
	 * 判断账户是否激活
	 */
	@Transient
    private boolean enabled = true;


	@Override
	public String getUsername() {
		return this.userCode;
	}

}