package com.lqkj.cmlcp.module.authority.repository;

import com.lqkj.cmlcp.module.authority.domain.UserInfo;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Map;

@Repository
public interface UserInfoRepository extends JpaRepository<UserInfo, Integer> {

    @Query(nativeQuery = true,
            value = "select * from user_info t where user_code = :userCode")
    UserInfo findByUserCode(@Param("userCode") String userCode);

    @Modifying
    @Query(nativeQuery = true,
            value = "update user_info set login_error_count = 0, locking = false, lock_time = null where id = :userId")
    void cleanLockStatus(@Param("userId") Integer userId);

    @Transactional
    @Modifying
    @Query(nativeQuery = true,
            value = "INSERT INTO user_info (id, user_code, display_name, password, authorization_code, head_img, " +
                    "file_save_path, has_auth, login_error_count, locking, lock_time, update_time, has_manage) " +
                    "VALUES (1, 'admin', '超级管理员', '$2a$10$OIBK8kKBDY07OS4CcVdx9e2GdxKH4T2lqWfDXgubjwZbxbis5.vSu', '87449007', " +
                    "NULL, NULL, 't', 0, 'f', NULL, now(), 't');"
    )
    void initSuperAdmin();

    @Transactional
    @Modifying
    @Query(nativeQuery = true,
            value = "ALTER SEQUENCE user_info_id_seq RESTART WITH 3"
    )
    void initUserIdSeq();

    @Transactional
    @Modifying
    @Query(nativeQuery = true,
            value = "insert into user_role values (1, 1)"
    )
    void initSuperAdminRole();

    @Query(nativeQuery = true,
            value = "select role_id from user_role where user_id = :userId")
    List<Integer> findUserRole(@Param("userId") Integer userId);


    @Query(nativeQuery = true,
            value = "select count(*) = 1 " +
                    "from user_info natural join user_role natural join role_authority " +
                    "where user_id = :userId and authority_id = 6 "
    )
    Boolean hasAuth(Integer userId);


    @Query(nativeQuery = true,
            value = "select ai.authority_id, en_name as \"name\", route as \"path\", component, redirect, authority_name as title, icon, parent_id " +
                    "from authority_info ai, role_authority ra, user_role ur, user_info ui " +
                    "where ui.user_code = :userCode " +
                    "and ur.user_id = ui.id " +
                    "and ur.role_id = ra.role_id " +
                    "and ra.authority_id = ai.authority_id " +
                    "order by ai.parent_id, ai.order_id"
    )
    List<Map<String, Object>> queryAuthWithUserCode(String userCode);

    @Query(nativeQuery = true,
            value = "select * from user_info " +
                    "where id != 1 " +
                    "and (:userCode = '' or user_code like concat('%', :userCode, '%')) " +
                    "and (:displayName = '' or display_name like concat('%', :displayName, '%')) " +
                    "order by update_time desc"
    )
    Page<UserInfo> pageQueryV2(@Param("userCode") String userCode,
                               @Param("displayName") String displayName,
                               Pageable pageable);

    @Query(nativeQuery = true,
            value = "select count(*) > 0 from user_info where user_code = :userCode"
    )
    Boolean hasSameUserCode(@Param("userCode") String userCode);
}
