package com.lqkj.cmlcp.module.authority.service;

import com.lqkj.cmlcp.module.authority.domain.UserInfo;
import org.springframework.data.domain.Page;

import java.util.List;
import java.util.Map;

public interface UserInfoService{

    /**
     * 根据账号查询用户信息
     * @param userCode
     * @return
     */
    UserInfo findByUserCode(String userCode);

    /**
     * 账号是否锁定
     * @param userCode
     * @return
     */
    boolean isLocked(String userCode);

    /**
     * 更新登录错误次数/锁定用户
     * @param userCode
     * @return
     */
    String lockedUser(String userCode);

    /**
     * 解锁用户
     * @param userCode
     */
    void unlockedUser(String userCode);

    /**
     * 根据账号查询用户信息
     * @param username
     * @return
     */
    UserInfo selectByUserName(String username);

    List<Integer> findUserRole(Integer userId);

    /**
     * 根据账号查询用户信息
     * @param username
     * @return
     */
    UserInfo detailByUserCode(String username);

    /**
     * 获取管理菜单接口
     * @param username
     * @return
     */
    List<Map<String, Object>> findAuthListWithUserCode(String username);

    /**
     * 用户分页接口
     * @param userCode
     * @param displayName
     * @param page
     * @param pageSize
     * @return
     */
    Page<UserInfo> pageQuery(String userCode, String displayName, Integer page, Integer pageSize);

    UserInfo detail(Integer userId);

    String save(UserInfo userInfo);

    void delete(List<Integer> userIds);

    void updateInfo(String userCode, String displayName, String headImgPath);

    /**
     * 检测用户是否可以登录后台
     * @param userCode
     * @return
     */
    boolean check(String userCode);
}
