package com.lqkj.cmlcp.module.zone.domain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import io.hypersistence.utils.hibernate.type.json.JsonType;
import jakarta.persistence.*;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;
import org.hibernate.annotations.SQLDelete;
import org.hibernate.annotations.Type;
import org.hibernate.annotations.Where;

import java.util.Date;


/**
 * 作品/态势表
 */
@Entity
@Table(name = "zone_info")
@Accessors(chain = true)
@Data()
@NoArgsConstructor
@AllArgsConstructor
@SQLDelete(sql = "UPDATE zone_info SET is_delete = true WHERE id = ?")
@Where(clause = "is_delete = false")
public class ZoneInfo {

    /**
     * 作品id
     */
    @Id
    @Column(name = "id")
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Integer id;

    /**
     * 作品名称
     */
    @Column(name = "zone_name")
    private String zoneName;

    /**
     * 缩略图
     */
    @Column(name = "thumbnail")
    private String thumbnail;

    /**
     * 插槽数据
     */
    @Type(JsonType.class)
    @Column(name = "data_slotters", columnDefinition = "jsonb")
    private JSONArray dataSlotters;

    /**
     * 画布样式
     */
    @Type(JsonType.class)
    @Column(name = "canvas_style", columnDefinition = "jsonb")
    private JSONObject canvasStyle;

    /**
     * 画布数据
     */
    @Type(JsonType.class)
    @Column(name = "canvas_data", columnDefinition = "jsonb")
    private JSONArray canvasData;

    /**
     * 项目id
     */
    @Column(name = "project_id")
    private Integer projectId;

    /**
     * 态势类型
     */
    @Column(name = "posture_type")
    private Integer postureType;

    /**
     * 是否删除
     */
    @Column(name = "is_delete", columnDefinition = "boolean default false")
    private Boolean isDelete;

    /**
     * 创建时间
     */
    @JsonFormat(pattern = "YYYY-MM-dd HH:mm:ss", timezone = "Asia/Shanghai")
    private Date createTime;

    /**
     * 更新时间
     */
    @JsonFormat(pattern = "YYYY-MM-dd HH:mm:ss", timezone = "Asia/Shanghai")
    private Date updateTime;

    public ZoneInfo(Integer projectId) {
        this.projectId = projectId;
    }
}
