package com.lqkj.cmlcp.module.zone.service.impl;

import com.lqkj.cmlcp.module.zone.domain.ProjectInfo;
import com.lqkj.cmlcp.module.zone.repository.ProjectInfoRepository;
import com.lqkj.cmlcp.module.zone.service.ProjectInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;
import java.util.Objects;

@Service
@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
public class ProjectInfoServiceImpl implements ProjectInfoService {


    @Autowired
    private ProjectInfoRepository projectInfoRepository;

    @Override
    public Page<ProjectInfo> pageQuery(String projectName, Integer page, Integer pageSize) {
        return projectInfoRepository.pageQuery(projectName, PageRequest.of(page, pageSize));
    }

    @Override
    public void save(ProjectInfo projectInfo) {
        ProjectInfo oldProject = projectInfoRepository.findByProjectName(projectInfo.getProjectName());
        if (Objects.nonNull(projectInfo.getId()) && !projectInfo.getId().equals(oldProject.getId())) throw new RuntimeException("项目名称已存在");
        if (Objects.isNull(projectInfo.getId()) && Objects.nonNull(oldProject)) throw new RuntimeException("项目名称已存在");
        if (Objects.isNull(projectInfo.getId())) projectInfo.setCreateTime(new Date());
        if (Objects.nonNull(projectInfo.getId())) projectInfo.setCreateTime(projectInfoRepository.findById(projectInfo.getId()).get().getCreateTime());
        projectInfo.setIsDelete(false);
        projectInfo.setUpdateTime(new Date());
        projectInfoRepository.save(projectInfo);
    }

    @Override
    public void delete(List<Integer> ids) {
        projectInfoRepository.deleteAllById(ids);
    }

    @Override
    public List<ProjectInfo> getRBList(String name) {
        return projectInfoRepository.getRBList(name);
    }

    @Transactional
    @Override
    public void restoxre(List<Integer> ids) {
        projectInfoRepository.restoxre(ids);
    }
}
