package com.lqkj.cmlcp.module.zone.service.impl;

import com.lqkj.cmlcp.module.zone.domain.ZoneInfo;
import com.lqkj.cmlcp.module.zone.repository.ZoneInfoRepository;
import com.lqkj.cmlcp.module.zone.service.ZoneInfoService;
import jakarta.persistence.EntityManager;
import jakarta.persistence.PersistenceContext;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;
import java.util.Objects;

@Service
@Transactional(propagation = Propagation.SUPPORTS, readOnly = true)
public class ZoneInfoServiceImpl implements ZoneInfoService {

    @Autowired
    private ZoneInfoRepository zoneInfoRepository;

    @PersistenceContext
    private EntityManager entityManager;

    @Override
    public void save(ZoneInfo zoneInfo) {
        ZoneInfo oldzone = zoneInfoRepository.findByZoneNameAndProjectId(zoneInfo.getZoneName(), zoneInfo.getProjectId());
        if (Objects.nonNull(zoneInfo.getId()) && Objects.nonNull(oldzone)
                && !oldzone.getId().equals(zoneInfo.getId())) throw new RuntimeException("作品名称已存在");
        if (Objects.isNull(zoneInfo.getId()) && Objects.nonNull(oldzone)) throw new RuntimeException("作品名称已存在");
        if (Objects.isNull(zoneInfo.getId())) zoneInfo.setCreateTime(new Date());
        if (Objects.nonNull(zoneInfo.getId())) zoneInfo.setCreateTime(zoneInfoRepository.findById(zoneInfo.getId()).get().getCreateTime());
        zoneInfo.setIsDelete(false);
        zoneInfo.setUpdateTime(new Date());
        zoneInfoRepository.save(zoneInfo);
    }

    @Override
    public Page<ZoneInfo> pageQuery(String name, Integer page, Integer pageSize) {
        PageRequest pageRequest = PageRequest.of(page, pageSize);
        return zoneInfoRepository.pageQuery(name, pageRequest);
    }

    @Transactional
    @Override
    public void delete(List<Integer> ids) {
        zoneInfoRepository.deleteAllById(ids);
    }

    @Override
    public List<ZoneInfo> getList(Integer projectId) {
        return zoneInfoRepository.findAll(Example.of(new ZoneInfo(projectId)), Sort.by(Sort.Order.desc("updateTime")));
    }

    @Override
    public ZoneInfo findById(Integer id) {
        return zoneInfoRepository.findById(id).orElse(null);
    }

}
