create table authority_info (
                                authority_id         INT4                 not null,
                                parent_id            INT4                 null,
                                authority_name       VARCHAR(255)         null,
                                en_name              VARCHAR(255)         null,
                                route                VARCHAR(255)         null,
                                component            VARCHAR(255)         null,
                                redirect             VARCHAR(255)         null,
                                icon                 VARCHAR(255)         null,
                                order_id             INT4                 null,
                                constraint PK_AUTHORITY_INFO primary key (authority_id)
);

comment on table authority_info is
'权限信息：authority_info';

comment on column authority_info.authority_id is
'权限ID：authority_id';

comment on column authority_info.parent_id is
'父权限ID：parent_id';

comment on column authority_info.authority_name is
'权限名称：authority_name';

comment on column authority_info.en_name is
'英文名：en_name';

comment on column authority_info.route is
'路由地址：route';

comment on column authority_info.component is
'组件：component';

comment on column authority_info.redirect is
'重定向地址：redirect';

comment on column authority_info.icon is
'图标：icon';

comment on column authority_info.order_id is
'排序：order_id';

create table role_authority (
                                role_id              INT4                 not null,
                                authority_id         INT4                 not null,
                                constraint PK_ROLE_AUTHORITY primary key (role_id, authority_id)
);
comment on table role_authority is
'角色权限信息：role_authority';

comment on column role_authority.role_id is
'角色ID：role_id';

comment on column role_authority.authority_id is
'权限ID：authority_id';
insert into role_authority select 1,  generate_series (1, 11);

create table role_info (
                           role_id              SERIAL               not null,
                           role_name            VARCHAR(255)         null,
                           en_name              VARCHAR(255)         null,
                           update_time          TIMESTAMP            null,
                           constraint PK_ROLE_INFO primary key (role_id)
);
comment on table role_info is
'角色信息：role_info';

comment on column role_info.role_id is
'角色ID：role_id';

comment on column role_info.role_name is
'角色名称：role_name';

comment on column role_info.en_name is
'英文名称：en_name';

comment on column role_info.update_time is
'更新时间：update_time';

insert into role_info values
    (1, '超级管理员', 'superAdmin', now());

select nextval('role_info_role_id_seq');

/*==============================================================*/
/* Table: user_info                                             */
/*==============================================================*/
create table user_info (
   id              SERIAL               not null,
   user_code            VARCHAR(255)         null,
   display_name         VARCHAR(255)         null,
   password             VARCHAR(255)         null,
   authorization_code   VARCHAR(64)          null,
   head_img             VARCHAR(1024)        null,
   file_save_path       VARCHAR(1024)        null,
   has_auth             BOOL                 null,
   login_error_count    INT4                 null,
   locking              BOOL                 null,
   lock_time            TIMESTAMP            null,
   update_time          TIMESTAMP            null,
   has_manage           BOOLEAN              null,
   constraint PK_USER_INFO primary key (id)
);
comment on table user_info is
'用户信息：user_info';

comment on column user_info.id is
'用户ID：user_id';

comment on column user_info.user_code is
'登录账号：user_code';

comment on column user_info.display_name is
'显示名称：display_name';

comment on column user_info.password is
'登录密码：password';

comment on column user_info.authorization_code is
'授权码：authorization_code';

comment on column user_info.head_img is
'头像：head_img';

comment on column user_info.file_save_path is
'文件保存路径：file_save_path';

comment on column user_info.has_auth is
'是否有审核权限：has_auth';

comment on column user_info.login_error_count is
'登录错误次数：login_error_count';

comment on column user_info.locking is
'是否锁定：locking';

comment on column user_info.lock_time is
'锁定时间：lock_time';

comment on column user_info.update_time is
'更新时间：update_time';

comment on column user_info.has_manage is
'能否进入管理后台：has_manage';


/*==============================================================*/
/* Table: user_role                                             */
/*==============================================================*/
create table user_role (
                           role_id              INT4                 not null,
                           user_id              INT4                 not null,
                           constraint PK_USER_ROLE primary key (role_id, user_id)
);

comment on table user_role is
'用户角色：user_role';

comment on column user_role.role_id is
'角色ID：role_id';

comment on column user_role.user_id is
'用户ID：user_id';



create table zone_info (
                           id SERIAL NOT NULL,
                           zone_name VARCHAR(255) NULL,
                           thumbnail VARCHAR(255) NULL,
                           data_slotters jsonb NULL,
                           canvas_style jsonb NULL,
                           canvas_data jsonb NULL,
                           is_delete BOOL not null default false,
                           update_time TIMESTAMP NULL,
                           create_time TIMESTAMP NULL,
                           constraint PK_ZONE_INFO primary key (id)
);
comment on table zone_info is
'作品/模板：zone_info';

comment on column zone_info.id is
'作品ID：id';

comment on column zone_info.zone_name is
'作品名称：zone_name';

comment on column zone_info.thumbnail is
'缩略图：thumbnail';

comment on column zone_info.data_slotters is
'数据：data_slotters';

comment on column zone_info.canvas_style is
'画布样式：canvas_style';

comment on column zone_info.canvas_data is
'画布数据：canvas_data';

comment on column zone_info.is_delete is
'是否删除：is_delete 0:否 1:是' ;

comment on column zone_info.update_time is
'更新时间：update_time';

comment on column zone_info.create_time is
'创建时间：create_time';



create table config_info (
                             id SERIAL NOT NULL,
                             server_address VARCHAR(255) NULL,
                             map_token VARCHAR(1000) NULL,
                             map_id VARCHAR(255) NULL,
                             map_style_id VARCHAR(255) NULL,
                             ue_stream_address VARCHAR(255) NULL,
                             ue_h5_address VARCHAR(255) NULL,
                             constraint PK_CONFIG_INFO primary key (id)
);
comment on table config_info is
'系统配置：config_info';
comment on column config_info.id is
'主键：id';
comment on column config_info.server_address is
'服务地址：server_address';
comment on column config_info.map_token is
'地图token：map_token';
comment on column config_info.map_id is
'地图id：map_id';
comment on column config_info.map_style_id is
'地图样式id：map_style_id';
comment on column config_info.ue_stream_address is
'UE推流地址：ue_stream_address';
comment on column config_info.ue_h5_address is
'UE h5地址：ue_h5_address';



create table api_info(
                         id SERIAL NOT NULL,
                         name VARCHAR(255) NULL,
                         method VARCHAR(255) NULL,
                         url VARCHAR(255) NULL,
                         headers jsonb NULL,
                         params jsonb NULL,
                         data jsonb NULL,
                         type int NULL,
                         constraint PK_API_INFO primary key (id)
);
comment on table api_info is
'接口信息：api_info';
comment on column api_info.id is
'主键：id';
comment on column api_info.name is
'接口名称：name';
comment on column api_info.method is
'请求方式：method';
comment on column api_info.url is
'请求地址：url';
comment on column api_info.headers is
'请求头：headers';
comment on column api_info.params is
'请求参数：params';
comment on column api_info.data is
'请求体：data';
comment on column api_info.type is
'api类型：type 1:接口 2:mock';



create table project_info(
                             id SERIAL NOT NULL,
                             project_name VARCHAR(255) NULL,
                             thumbnail VARCHAR(255) NULL,
                             is_delete BOOL not null default false,
                             update_time TIMESTAMP NULL,
                             create_time TIMESTAMP NULL,
                             constraint PK_PROJECT_INFO primary key (id)
);
comment on table project_info is
'项目信息：project_info';
comment on column project_info.id is
'项目ID：id';
comment on column project_info.project_name is
'项目名称：project_name';
comment on column project_info.thumbnail is
'缩略图：thumbnail';
comment on column project_info.is_delete is
'是否删除：is_delete 0:否 1:是' ;
comment on column project_info.update_time is
'更新时间：update_time';
comment on column project_info.create_time is
'创建时间：create_time';
alter table zone_info add column project_id int;
comment on column zone_info.project_id is
'项目ID：project_id';
alter table zone_info add column posture_type int;
comment on column zone_info.posture_type is
'态势型：posture_type';